@@ -3,14 +3,15 @@
 #include <stdint.h>
 #include <errno.h>
 
-#include <skalibs/posixishard.h>
 #include <skalibs/uint32.h>
 #include <skalibs/bytestr.h>
 #include <skalibs/stralloc.h>
 #include <skalibs/unixmessage.h>
-#include <s6/s6-fdholder.h>
+#include <s6/fdholder.h>
 
-int s6_fdholder_list_cb (unixmessage_t const *m, void *p)
+#include <skalibs/posixishard.h>
+
+int s6_fdholder_list_cb (unixmessage const *m, void *p)
 {
   uint32_t n ;
   s6_fdholder_list_result_t *res = p ;
