@@ -24,6 +24,9 @@
 #define MAXFIELDS 16
 #define checkfields() if (n >= MAXFIELDS) strerr_dief1x(100, "too many option fields")
 
+#define notstartedyet(st) (!(st)->pid && !(st)->flagfinishing && (st)->flagpaused)
+#define isup(st) ((st)->pid && !(st)->flagfinishing)
+
 static int normallyup ;
 
 typedef void pr_func (buffer *, s6_svstatus_t const *) ;
@@ -53,12 +56,12 @@ static void pr_ready (buffer *b, s6_svstatus_t const *st)
 
 static void pr_paused (buffer *b, s6_svstatus_t const *st)
 {
-  buffer_putsnoflush(b, st->flagpaused ? "true" : "false") ;
+  buffer_putsnoflush(b, st->flagpaused && st->pid ? "true" : "false") ;
 }
 
 static void pr_pid (buffer *b, s6_svstatus_t const *st)
 {
-  if (st->pid && !st->flagfinishing)
+  if (isup(st) && !notstartedyet(st))
   {
     char fmt[PID_FMT] ;
     buffer_putnoflush(b, fmt, pid_fmt(fmt, st->pid)) ;
@@ -66,16 +69,6 @@ static void pr_pid (buffer *b, s6_svstatus_t const *st)
   else buffer_putsnoflush(b, "-1") ;
 }
 
-static void pr_pgid (buffer *b, s6_svstatus_t const *st)
-{
-  if (st->pgid > 0)
-  {
-    char fmt[PID_FMT] ;
-    buffer_putnoflush(b, fmt, pid_fmt(fmt, st->pgid)) ;
-  }
-  else buffer_putsnoflush(b, "-1") ;
-}
-
 static void pr_tain (buffer *b, tain const *a)
 {
   char fmt[TIMESTAMP] ;
@@ -112,7 +105,7 @@ static void pr_readyseconds (buffer *b, s6_svstatus_t const *st)
 
 static void pr_exitcode (buffer *b, s6_svstatus_t const *st)
 {
-  int e = st->pid && !st->flagfinishing ? -1 :
+  int e = notstartedyet(st) || isup(st) ? -1 :
           WIFEXITED(st->wstat) ? WEXITSTATUS(st->wstat) : -1 ;
   char fmt[INT_FMT] ;
   buffer_putnoflush(b, fmt, int_fmt(fmt, e)) ;
@@ -120,7 +113,7 @@ static void pr_exitcode (buffer *b, s6_svstatus_t const *st)
 
 static void pr_signum (buffer *b, s6_svstatus_t const *st)
 {
-  int e = st->pid && !st->flagfinishing ? -1 :
+  int e = notstartedyet(st) || isup(st) ? -1 :
             WIFSIGNALED(st->wstat) ? WTERMSIG(st->wstat) : -1 ;
   char fmt[INT_FMT] ;
   buffer_putnoflush(b, fmt, int_fmt(fmt, e)) ;
@@ -128,7 +121,7 @@ static void pr_signum (buffer *b, s6_svstatus_t const *st)
 
 static void pr_signal (buffer *b, s6_svstatus_t const *st)
 {
-  int e = st->pid && !st->flagfinishing ? -1 :
+  int e = notstartedyet(st) || isup(st) ? -1 :
             WIFSIGNALED(st->wstat) ? WTERMSIG(st->wstat) : -1 ;
   if (e == -1) buffer_putsnoflush(b, "NA") ;
   else
@@ -149,7 +142,7 @@ static funcmap_t const fmtable[] =
   { .s = "exitcode", .f = &pr_exitcode },
   { .s = "normallyup", .f = &pr_normallyup },
   { .s = "paused", .f = &pr_paused },
-  { .s = "pgid", .f = &pr_pgid },
+  { .s = "pgid", .f = &pr_pid },
   { .s = "pid", .f = &pr_pid },
   { .s = "ready", .f = &pr_ready },
   { .s = "readyfor", .f = &pr_readyseconds },
@@ -190,21 +183,22 @@ static unsigned int parse_options (char const *arg, pr_func_ref *fields, unsigne
 static void legacy (s6_svstatus_t *st, int flagnum)
 {
   s6_svstatus_t status = *st ;
-  int isup = status.pid && !status.flagfinishing ;
   char fmt[UINT64_FMT] ;
 
-  if (isup)
+  if (isup(st))
   {
     buffer_putnoflush(buffer_1small,"up (pid ", 8) ;
     buffer_putnoflush(buffer_1small, fmt, pid_fmt(fmt, status.pid)) ;
     buffer_putnoflush(buffer_1small, " pgid ", 6) ;
-    buffer_putnoflush(buffer_1small, fmt, pid_fmt(fmt, status.pgid)) ;
+    buffer_putnoflush(buffer_1small, fmt, pid_fmt(fmt, status.pid)) ;
     buffer_putnoflush(buffer_1small, ") ", 2) ;
   }
   else
   {
     buffer_putnoflush(buffer_1small, "down (", 6) ;
-    if (WIFSIGNALED(status.wstat))
+    if (notstartedyet(st))
+      buffer_putsnoflush(buffer_1small, "not started yet") ;
+    else if (WIFSIGNALED(status.wstat))
     {
       buffer_putnoflush(buffer_1small, "signal ", 7) ;
       if (flagnum)
@@ -223,22 +217,25 @@ static void legacy (s6_svstatus_t *st, int flagnum)
     buffer_putnoflush(buffer_1small, ") ", 2) ;
   }
 
-  tain_sub(&status.stamp, &STAMP, &status.stamp) ;
-  buffer_putnoflush(buffer_1small, fmt, uint64_fmt(fmt, status.stamp.sec.x)) ;
-  buffer_putnoflush(buffer_1small, " seconds", 8) ;
+  if (!notstartedyet(st))
+  {
+    tain_sub(&status.stamp, &STAMP, &status.stamp) ;
+    buffer_putnoflush(buffer_1small, fmt, uint64_fmt(fmt, status.stamp.sec.x)) ;
+    buffer_putnoflush(buffer_1small, " seconds", 8) ;
+  }
 
-  if (isup && !normallyup)
+  if (isup(st) && !normallyup)
     buffer_putnoflush(buffer_1small, ", normally down", 15) ;
-  if (!isup && normallyup)
+  if (!isup(st) && normallyup)
     buffer_putnoflush(buffer_1small, ", normally up", 13) ;
-  if (isup && status.flagpaused)
+  if (isup(st) && status.flagpaused)
     buffer_putnoflush(buffer_1small, ", paused", 8) ;
-  if (!isup && status.flagwantup)
+  if (!isup(st) && status.flagwantup)
     buffer_putnoflush(buffer_1small, ", want up", 9) ;
-  if (isup && !status.flagwantup)
+  if (isup(st) && !status.flagwantup)
     buffer_putnoflush(buffer_1small, ", want down", 11) ;
 
-  if (status.flagready)
+  if (status.flagready && !notstartedyet(st))
   {
     tain_sub(&status.readystamp, &STAMP, &status.readystamp) ;
     buffer_putnoflush(buffer_1small, ", ready ", 8) ;
@@ -270,7 +267,7 @@ int main (int argc, char const *const *argv)
         case 'N' : checkfields() ; fields[n++] = &pr_normallyup ; break ;
         case 'r' : checkfields() ; fields[n++] = &pr_ready ; break ;
         case 'p' : checkfields() ; fields[n++] = &pr_pid ; break ;
-        case 'g' : checkfields() ; fields[n++] = &pr_pgid ; break ;
+        case 'g' : checkfields() ; fields[n++] = &pr_pid ; break ;
         case 'e' : checkfields() ; fields[n++] = &pr_exitcode ; break ;
         case 's' : checkfields() ; fields[n++] = &pr_signal ; break ;
         case 't' : checkfields() ; fields[n++] = &pr_upseconds ; break ;
